Index: /trunk/src/bp-core/deprecated/11.0.php
===================================================================
--- /trunk/src/bp-core/deprecated/11.0.php	(revision 13302)
+++ /trunk/src/bp-core/deprecated/11.0.php	(revision 13303)
@@ -57,2 +57,22 @@
 	return array();
 }
+
+/**
+ * Catch the arguments for buttons
+ *
+ * @since 3.0.0
+ * @deprecated 11.0.0
+ *
+ * @param array $buttons The arguments of the button that BuddyPress is about to create.
+ *
+ * @return array An empty array to stop the button creation process.
+ */
+function bp_nouveau_blogs_catch_button_args( $button = array() ) {
+	_deprecated_function( __FUNCTION__, '11.0.0' );
+
+	// Globalize the arguments so that we can use it  in bp_nouveau_get_blogs_buttons().
+	bp_nouveau()->blogs->button_args = $button;
+
+	// return an empty array to stop the button creation process
+	return array();
+}
Index: /trunk/src/bp-templates/bp-nouveau/includes/blogs/functions.php
===================================================================
--- /trunk/src/bp-templates/bp-nouveau/includes/blogs/functions.php	(revision 13302)
+++ /trunk/src/bp-templates/bp-nouveau/includes/blogs/functions.php	(revision 13303)
@@ -117,21 +117,4 @@
 
 /**
- * Catch the arguments for buttons
- *
- * @since 3.0.0
- *
- * @param array $buttons The arguments of the button that BuddyPress is about to create.
- *
- * @return array An empty array to stop the button creation process.
- */
-function bp_nouveau_blogs_catch_button_args( $button = array() ) {
-	// Globalize the arguments so that we can use it  in bp_nouveau_get_blogs_buttons().
-	bp_nouveau()->blogs->button_args = $button;
-
-	// return an empty array to stop the button creation process
-	return array();
-}
-
-/**
  * Add settings to the customizer for the blogs component.
  *
Index: /trunk/src/bp-templates/bp-nouveau/includes/blogs/template-tags.php
===================================================================
--- /trunk/src/bp-templates/bp-nouveau/includes/blogs/template-tags.php	(revision 13302)
+++ /trunk/src/bp-templates/bp-nouveau/includes/blogs/template-tags.php	(revision 13303)
@@ -200,57 +200,41 @@
 		}
 
-		/*
-		 * This filter workaround is waiting for a core adaptation
-		 * so that we can directly get the groups button arguments
-		 * instead of the button.
-		 *
-		 * See https://buddypress.trac.wordpress.org/ticket/7126
-		 */
-		add_filter( 'bp_get_blogs_visit_blog_button', 'bp_nouveau_blogs_catch_button_args', 100, 1 );
-
-		bp_get_blogs_visit_blog_button();
-
-		remove_filter( 'bp_get_blogs_visit_blog_button', 'bp_nouveau_blogs_catch_button_args', 100, 1 );
-
-		if ( isset( bp_nouveau()->blogs->button_args ) && bp_nouveau()->blogs->button_args ) {
-			$button_args = bp_nouveau()->blogs->button_args ;
-
-			// If we pass through parent classes add them to $button array
-			$parent_class = '';
-			if ( ! empty( $args['parent_attr']['class'] ) ) {
-				$parent_class = $args['parent_attr']['class'];
-			}
-
-			// Set defaults if not set.
-			$button_args = array_merge( array(
-				'wrapper_id' => '',
-				'link_id'    => '',
-				'link_rel'   => ''
-			), $button_args );
-
-			$buttons['visit_blog'] = array(
-				'id'                => 'visit_blog',
-				'position'          => 5,
-				'component'         => $button_args['component'],
-				'must_be_logged_in' => $button_args['must_be_logged_in'],
-				'block_self'        => $button_args['block_self'],
-				'parent_element'    => $parent_element,
-				'button_element'    => $button_element,
-				'link_text'         => $button_args['link_text'],
-				'parent_attr'       => array(
-					'id'              => $button_args['wrapper_id'],
-					'class'           => $parent_class,
-				),
-				'button_attr'       => array(
-					'href'             => $button_args['link_href'],
-					'id'               => $button_args['link_id'],
-					'class'            => $button_args['link_class'] . ' button',
-					'rel'              => $button_args['link_rel'],
-					'title'            => '',
-				),
-			);
-
-			unset( bp_nouveau()->blogs->button_args );
-		}
+		$button_args = bp_get_blogs_visit_blog_button_args();
+
+		// If we pass through parent classes add them to $button array
+		$parent_class = '';
+		if ( ! empty( $args['parent_attr']['class'] ) ) {
+			$parent_class = $args['parent_attr']['class'];
+		}
+
+		// Set defaults if not set.
+		$button_args = array_merge( array(
+			'wrapper_id' => '',
+			'link_id'    => '',
+			'link_rel'   => ''
+		), $button_args );
+
+		$buttons['visit_blog'] = array(
+			'id'                => 'visit_blog',
+			'position'          => 5,
+			'component'         => $button_args['component'],
+			'must_be_logged_in' => $button_args['must_be_logged_in'],
+			'block_self'        => $button_args['block_self'],
+			'parent_element'    => $parent_element,
+			'button_element'    => $button_element,
+			'link_text'         => $button_args['link_text'],
+			'link_title'        => $button_args['link_title'],
+			'parent_attr'       => array(
+				'id'              => $button_args['wrapper_id'],
+				'class'           => $parent_class,
+			),
+			'button_attr'       => array(
+				'href'             => $button_args['link_href'],
+				'id'               => $button_args['link_id'],
+				'class'            => $button_args['link_class'] . ' button',
+				'rel'              => $button_args['link_rel'],
+				'title'            => '',
+			),
+		);
 
 		/**
Index: /trunk/src/class-buddypress.php
===================================================================
--- /trunk/src/class-buddypress.php	(revision 13302)
+++ /trunk/src/class-buddypress.php	(revision 13303)
@@ -560,4 +560,5 @@
 			require $this->plugin_dir . 'bp-core/deprecated/9.0.php';
 			require $this->plugin_dir . 'bp-core/deprecated/10.0.php';
+			require $this->plugin_dir . 'bp-core/deprecated/11.0.php';
 		}
 

Index: /trunk/src/bp-blogs/bp-blogs-template.php
===================================================================
--- /trunk/src/bp-blogs/bp-blogs-template.php	(revision 13302)
+++ /trunk/src/bp-blogs/bp-blogs-template.php	(revision 13303)
@@ -1543,16 +1543,19 @@
  * Output button for visiting a blog in a loop.
  *
  * @see bp_get_blogs_visit_blog_button() for description of arguments.
  *
  * @param array|string $args See {@link bp_get_blogs_visit_blog_button()}.
  */
 function bp_blogs_visit_blog_button( $args = '' ) {
 	echo bp_get_blogs_visit_blog_button( $args );
 }
-	/**
-	 * Return button for visiting a blog in a loop.
+
+	/**
+	 * Return the arguments of the button for visiting a blog in a loop.
 	 *
 	 * @see BP_Button for a complete description of arguments and return
 	 *      value.
+	 *
+	 * @since 11.0.0
 	 *
 	 * @param array|string $args {
@@ -1567,9 +1570,10 @@
 	 *     @type string $link_class        Default: 'blog-button visit'.
 	 *     @type string $link_text         Default: 'Visit Site'.
+	 *     @type string $link_title        Default: 'Visit Site'.
 	 * }
-	 * @return string The HTML for the Visit button.
-	 */
-	function bp_get_blogs_visit_blog_button( $args = '' ) {
-		$button = bp_parse_args(
+	 * @return array Thhe arguments of the button for visiting a blog in a loop.
+	 */
+	function bp_get_blogs_visit_blog_button_args( $args = '' ) {
+		$button_args = bp_parse_args(
 			$args,
 			array(
@@ -1582,4 +1586,5 @@
 				'link_class'        => 'blog-button visit',
 				'link_text'         => __( 'Visit Site', 'buddypress' ),
+				'link_title'        => __( 'Visit Site', 'buddypress' ),
 			)
 		);
@@ -1590,7 +1595,28 @@
 		 * @since 1.2.10
 		 *
-		 * @param array $button Array of arguments to be used for the button to visit a blog.
-		 */
-		return bp_get_button( apply_filters( 'bp_get_blogs_visit_blog_button', $button ) );
+		 * @param array $button_args Array of arguments to be used for the button to visit a blog.
+		 */
+		return apply_filters( 'bp_get_blogs_visit_blog_button', $button_args );
+	}
+
+	/**
+	 * Return button for visiting a blog in a loop.
+	 *
+	 * @see BP_Button for a complete description of arguments and return
+	 *      value.
+	 *
+	 * @see bp_get_blogs_visit_blog_button_args() for description of arguments.
+	 *
+	 * @param array|string $args See {@link bp_get_blogs_visit_blog_button_args()}.
+	 * @return string The HTML for the Visit button.
+	 */
+	function bp_get_blogs_visit_blog_button( $args = '' ) {
+		$button_args = bp_get_blogs_visit_blog_button_args( $args );
+
+		if ( ! array_filter( $button_args ) ) {
+			return '';
+		}
+
+		return bp_get_button( $button_args );
 	}
 
@@ -1543,16 +1543,19 @@
  * Output button for visiting a blog in a loop.
  *
- * @see bp_get_blogs_visit_blog_button() for description of arguments.
- *
- * @param array|string $args See {@link bp_get_blogs_visit_blog_button()}.
+ * @see bp_get_blogs_visit_blog_button_args() for description of arguments.
+ *
+ * @param array|string $args See {@link bp_get_blogs_visit_blog_button_args()}.
  */
 function bp_blogs_visit_blog_button( $args = '' ) {